#
# spec file for package jackson-datatypes-collections
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jackson-datatypes-collections
Version:        2.17.1
Release:        1.1
Summary:        Jackson datatypes: collections
License:        Apache-2.0
URL:            https://github.com/FasterXML/jackson-datatypes-collections
Source0:        https://github.com/FasterXML/jackson-datatypes-collections/archive/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(com.carrotsearch:hppc)
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-core) >= 2.16
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-databind) >= 2.16
BuildRequires:  mvn(com.fasterxml.jackson:jackson-base:pom:) >= 2.16
BuildRequires:  mvn(com.google.code.maven-replacer-plugin:replacer)
BuildRequires:  mvn(com.google.guava:guava)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildArch:      noarch

%description
This is a multi-module umbrella project for various Jackson
Data-type modules to support 3rd party Collection libraries.

Currently included are:
* Guava data-type
* HPPC data-type
* PCollections data-type

%package -n jackson-datatype-guava
Summary:        Add-on module for Jackson which handles Guava data-types

%description -n jackson-datatype-guava
Add-on datatype-support module for Jackson that handles
Guava types (currently mostly just collection ones).

%package -n jackson-datatype-hppc
Summary:        Add-on module for Jackson to support HPPC data-types

%description -n jackson-datatype-hppc
Jackson data-type module to support JSON serialization and
deserialization of High-Performance Primitive Collections
data-types.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

sed -i 's/\r//' hppc/src/main/resources/META-INF/LICENSE
cp -p hppc/src/main/resources/META-INF/LICENSE .

# Deps are missing for these modules:
%pom_disable_module eclipse-collections
%pom_disable_module pcollections

%pom_remove_plugin -r :moditect-maven-plugin
%pom_remove_plugin -r :gradle-module-metadata-maven-plugin

%build
%{mvn_build} -f -s -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles-jackson-datatypes-collections
%doc README.md release-notes
%license LICENSE

%files -n jackson-datatype-guava -f .mfiles-jackson-datatype-guava
%doc guava/README.md guava/release-notes
%license LICENSE

%files -n jackson-datatype-hppc -f .mfiles-jackson-datatype-hppc
%doc hppc/README.md hppc/release-notes
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Mon May 20 2024 Gus Kenion <gus.kenion@suse.com>
- Update to 2.17.1
  * #149: (guava) Update CI to use Matrix Build to test against
    different Guava versions
- Includes changes from 2.17
  * #118: (guava) Support @JsonFormat(shape=STRING) on Range<T>
    (contributed by Muhammad K)
  * #124: (guava) Some deserializers throw unexpected
    `NullPointerException` when handling invalid input (contributed
    by Arthur C)
  * #135 (guava) Add deserialization support for bracket notation
    Range (contributed by Muhammad K)
  * #136 (guava) Fix for failing Guava `Optional` test (contributed
    by Muhammad K)
  * #138 (guava) `GuavaCollectionDeserializer` still throws NPE in
    some circumstances (contributed by Arthur C)
  * #140 (guava) `Cache` deserialization fails with NPE for `null`
    valued entries
  * #142 (guava) `RangeSet` deserializer fails for content `null`s
    with NPE
- Includes changes from 2.16.2
  * #145: `GuavaOptionalDeserializer.getEmptyValue()` should not
    call itself recursively
* Fri Mar  8 2024 Gus Kenion <gkenion@suse.com>
- Update to 2.16.1
  * 2.16.1 (24-Dec-2023) - no significant changes since 2.16.0
  * 2.16.0 (15-Nov-2023)
    + #90: (guava) Cache Serialization serializes empty contents
    + #113: (guava) Update default Guava dependency for Jackson
    2.16 from Guava 23.x to 25.x
    + #116: (guava) Suppport simple deserialization of Cache
    + #117: (guava) ImmutableRangeSet fails to deserialize without
    explicit deserializer
    + #117: (pcollections) PCollections module info
    (module-info.class) incorrect
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Mon Aug 21 2023 Fridrich Strba <fstrba@suse.com>
- Version update to 2.15.2
  * No changes since 2.15.0
  * 2.15.0 (23-Apr-2023)
    + #7: (guava) Add support for 'WRITE_SORTED_MAP_ENTRIES' for
    Guava 'Multimap's
    + #92: (guava) '@JsonDeserialize.contentConverter' does not work
    for non-builtin collections
    + #102: (guava) accept lowerCase enums for 'Range' 'BoundType'
    serialization
    + #105: (guava) Update Guava dependency to 23.6.1-jre
    (from 21.0)
    + #106: (guava) There maybe a misusage in
    GuavaMultimapDeserializer.findTransformer method
  * 2.14.3 (05-May-2023)
    + #92: (guava) '@JsonDeserialize.contentConverter' does not work
    for non-builtin collections
    + #104: 'ArrayListMultimapDeserializer' does not support
    multimaps inside another object as a property
  * 2.13.4 (03-Sep-2022)
    + #94: Eclipse Collection serialization for Pairs does not work
    when upgrading to EC version 11.0.0
* Wed Jun 15 2022 Fridrich Strba <fstrba@suse.com>
- Version upgrade to 2.13.3
  * 2.13.3 (14-May-2022)
  * 2.13.2 (06-Mar-2022)
  * 2.13.1 (19-Dec-2021)
  * No changes since 2.13.0
* Wed Oct 20 2021 Fridrich Strba <fstrba@suse.com>
- Version upgrade to 2.13.0
  * 2.13.0 (30-Sep-2021)
    + #85: (eclipse-collections) Update eclipse-collections to
    version 10 and implement Triple deserialization. Still
    compatible with older EC versions
    + (guava) Serialize 'Cache' instances as empty Objects
    (see #90)
  * 2.12.2 (03-Mar-2021)
    + Add missing "provides Module" for eclipse-collections
    module-info (JPMS)
  * 2.12.0 (29-Nov-2020)
    + #25: (guava) SetMultimap should be deserialized to a
    LinkedHashMultimap by default
    + #79: (guava)  Guava's RangeHelper causing NPE in
    PropertyNamingStrategy
    + Add Gradle Module Metadata
    + Update "preferred" Guava version to 21.0
  * 2.11.4 (12-Dec-2020)
    + Add missing "LICENSE" file for Guava- and Eclipse-collections
    modules
    + Add missing SPI metadata for auto-detecti Eclipse-collections
    module
  * 2.11.3 (02-Oct-2020)
    + #71 (eclipse-collections) Can not deserialize concrete class
    instance inside nested immutable eclipse-collection
  * 2.11.2 (02-Aug-2020)
    + #68: Support for Guava 29
  * 2.10.5 (21-Jul-2020)
    + #67: Guava collection deserialization failure with
    'Nulls.AS_EMPTY'
* Wed May 12 2021 Fridrich Strba <fstrba@suse.com>
- Do not build against the legacy guava20 package, build against
  guava 30.1.1 instead, with source level 8
* Fri Jul 24 2020 Fridrich Strba <fstrba@suse.com>
- Initial packaging of jackson-datatype-collections 2.10.3
